Struct widestring::MissingNulError [−][src]
pub struct MissingNulError<C>(_);
An error returned from UCString and UCStr to indicate that a terminating nul value
was missing.
The error optionally returns the ownership of the invalid vector whenever a vector was owned.
Methods
impl<C: UChar> MissingNulError<C>[src]
impl<C: UChar> MissingNulError<C>pub fn into_vec(self) -> Option<Vec<C>>[src]
pub fn into_vec(self) -> Option<Vec<C>>Consumes this error, returning the underlying vector of u16 values which generated the
error in the first place.